@@ -11,6 +11,7 @@ pub mod vobsub;
 pub mod common;
 
 use SubtitleFile;
+use encoding::{EncodingRef, DecoderTrap};
 use errors::*;
 
 
@@ -26,10 +27,10 @@ pub enum SubtitleFormat {
     /// .idx file
     VobSubIdx,
 
-    /// .sub file (VobSub/binary)
+    /// .sub file (`VobSub`/binary)
     VobSubSub,
 
-    /// .sub file (MicroDVD/text)
+    /// .sub file (`MicroDVD`/text)
     MicroDVD,
 }
 
@@ -52,7 +53,7 @@ impl SubtitleFormat {
 /// Calling the function with the full file path or simply a `get_subtitle_format_by_ending(".srt")`
 /// both work. Returns `None` if subtitle format could not be recognized.
 ///
-/// Because the `.sub` file ending is ambiguous (both MicroDVD and VobSub use that ending) the
+/// Because the `.sub` file ending is ambiguous (both `MicroDVD` and `VobSub` use that ending) the
 /// function will return `None` in that case. Instead, use the content-aware `get_subtitle_format`
 /// to handle this case correctly.
 pub fn get_subtitle_format_by_ending(ending: &str) -> Option<SubtitleFormat> {
@@ -73,7 +74,7 @@ pub fn get_subtitle_format_by_ending(ending: &str) -> Option<SubtitleFormat> {
 /// Works exactly like `get_subtitle_format_by_ending`, but instead of `None` a `UnknownFileFormat`
 /// will be returned (for simpler error handling).
 pub fn get_subtitle_format_by_ending_err(ending: &str) -> Result<SubtitleFormat> {
-    get_subtitle_format_by_ending(ending).ok_or(ErrorKind::UnknownFileFormat.into())
+    get_subtitle_format_by_ending(ending).ok_or_else(|| ErrorKind::UnknownFileFormat.into())
 }
 
 /// Returns the subtitle format by the file ending and provided content.
@@ -86,7 +87,12 @@ pub fn get_subtitle_format_by_ending_err(ending: &str) -> Result<SubtitleFormat>
 pub fn get_subtitle_format(ending: &str, content: &[u8]) -> Option<SubtitleFormat> {
     if ending.ends_with(".sub") {
         // test for VobSub .sub magic number
-        if content.iter().take(4).cloned().eq([0x00, 0x00, 0x01, 0xba].iter().cloned()) {
+        if content.iter().take(4).cloned().eq(
+            [0x00, 0x00, 0x01, 0xba]
+                .iter()
+                .cloned(),
+        )
+        {
             Some(SubtitleFormat::VobSubSub)
         } else {
             Some(SubtitleFormat::MicroDVD)
@@ -101,21 +107,29 @@ pub fn get_subtitle_format(ending: &str, content: &[u8]) -> Option<SubtitleForma
 /// Works exactly like `get_subtitle_format`, but instead of `None` a `UnknownFileFormat`
 /// will be returned (for simpler error handling).
 pub fn get_subtitle_format_err(ending: &str, content: &[u8]) -> Result<SubtitleFormat> {
-    get_subtitle_format(ending, content).ok_or(ErrorKind::UnknownFileFormat.into())
+    get_subtitle_format(ending, content).ok_or_else(|| ErrorKind::UnknownFileFormat.into())
 }
 
 // This trick works around the limitation, that trait objects can not require Sized (or Clone).
-pub trait ClonableSubtitleFile: SubtitleFile {
-    fn clone(&self) -> Box<ClonableSubtitleFile>;
+pub trait ClonableSubtitleFile: SubtitleFile + Send + Sync {
+    fn clone_box(&self) -> Box<ClonableSubtitleFile>;
 }
 impl<T> ClonableSubtitleFile for T
-    where T: SubtitleFile + Clone + 'static
+where
+    T: SubtitleFile + Clone + Send + Sync + 'static,
 {
-    fn clone(&self) -> Box<ClonableSubtitleFile> {
+    fn clone_box(&self) -> Box<ClonableSubtitleFile> {
         Box::new(Clone::clone(self))
     }
 }
 
+// We can now implement Clone manually by forwarding to clone_box.
+impl Clone for Box<ClonableSubtitleFile> {
+    fn clone(&self) -> Box<ClonableSubtitleFile> {
+        self.clone_box()
+    }
+}
+
 /// Parse text subtitles, invoking the right parser given by `format`.
 ///
 /// Returns an `Err(ErrorKind::TextFormatOnly)` if attempted on a binary file format.
@@ -133,26 +147,42 @@ pub fn parse_str(format: SubtitleFormat, content: &str, fps: f64) -> Result<Box<
     }
 }
 
+/// Helper function for text subtitles for byte-to-text decoding.
+fn decode_bytes_to_string(content: &[u8], encoding: EncodingRef) -> Result<String> {
+    encoding.decode(content, DecoderTrap::Strict)
+            .map_err(|e| Error::from(e.to_string()))
+            .chain_err(|| Error::from(ErrorKind::DecodingError))
+}
+
 /// Parse all subtitle formats, invoking the right parser given by `format`.
 ///
-/// Decodes the bytes to a String for text formats (assuming utf-8 encoding).
-///
 /// # Mandatory format specific options
 ///
 /// Some subtitle formats require additional paramters to work as expected. If you want to parse
 /// a specific format that has no additional paramters, you can use the `parse` function of
 /// the respective `***File` struct.
 ///
-/// `fps`: this paramter is used for MicroDVD `.sub` files. These files do not store timestamps in
+/// `encoding`: to parse a text-based subtitle format, a character encoding is needed
+///
+/// `fps`: this paramter is used for `MicroDVD` `.sub` files. These files do not store timestamps in
 /// seconds/minutes/... but in frame numbers. So the timing `0 to 30` means "show subtitle for one second"
 /// for a 30fps video, and "show subtitle for half second" for 60fps videos. The parameter specifies how
 /// frame numbers are converted into timestamps.
-pub fn parse_bytes(format: SubtitleFormat, content: &[u8], fps: f64) -> Result<Box<ClonableSubtitleFile>> {
+pub fn parse_bytes(format: SubtitleFormat, content: &[u8], encoding: EncodingRef, fps: f64) -> Result<Box<ClonableSubtitleFile>> {
     match format {
-        SubtitleFormat::SubRip => Ok(Box::new(srt::SrtFile::parse(&String::from_utf8(content.to_vec())?)?)),
-        SubtitleFormat::SubStationAlpha => Ok(Box::new(ssa::SsaFile::parse(&String::from_utf8(content.to_vec())?)?)),
-        SubtitleFormat::VobSubIdx => Ok(Box::new(idx::IdxFile::parse(&String::from_utf8(content.to_vec())?)?)),
+        SubtitleFormat::SubRip => Ok(Box::new(srt::SrtFile::parse(
+            &decode_bytes_to_string(content, encoding)?,
+        )?)),
+        SubtitleFormat::SubStationAlpha => Ok(Box::new(ssa::SsaFile::parse(
+            &decode_bytes_to_string(content, encoding)?,
+        )?)),
+        SubtitleFormat::VobSubIdx => Ok(Box::new(idx::IdxFile::parse(
+            &decode_bytes_to_string(content, encoding)?,
+        )?)),
         SubtitleFormat::VobSubSub => Ok(Box::new(vobsub::VobFile::parse(content)?)),
-        SubtitleFormat::MicroDVD => Ok(Box::new(microdvd::MdvdFile::parse(&String::from_utf8(content.to_vec())?, fps)?)),
+        SubtitleFormat::MicroDVD => Ok(Box::new(microdvd::MdvdFile::parse(
+            &decode_bytes_to_string(content, encoding)?,
+            fps,
+        )?)),
     }
 }
