@@ -15,13 +15,14 @@
 //!
 //! Files can be parsed, modified and saved again - some formats can be created from scratch.
 //! The focus is on non-destructive parsing, meaning that formatting and other information are preserved
-//! if not explicitely changed. Note that not all features of a specific subtitle format are supported.
+//! if not explicitely changed.
 
 #[macro_use]
 extern crate error_chain;
 extern crate combine;
 extern crate vobsub;
 extern crate itertools;
+extern crate encoding;
 
 mod formats;
 
@@ -31,16 +32,16 @@ pub mod timetypes;
 /// Error-chain generated error types.
 pub mod errors;
 
-pub use formats::srt::SrtFile;
-pub use formats::idx::IdxFile;
-pub use formats::ssa::SsaFile;
-pub use formats::vobsub::VobFile;
-pub use formats::microdvd::MdvdFile;
-pub use formats::SubtitleFormat;
-pub use formats::{get_subtitle_format, get_subtitle_format_by_ending, get_subtitle_format_by_ending_err, get_subtitle_format_err, parse_bytes,
-                  parse_str};
 
 use errors::*;
+pub use formats::{get_subtitle_format, get_subtitle_format_by_ending, get_subtitle_format_by_ending_err, get_subtitle_format_err, parse_bytes,
+                  parse_str};
+pub use formats::SubtitleFormat;
+pub use formats::idx::IdxFile;
+pub use formats::microdvd::MdvdFile;
+pub use formats::srt::SrtFile;
+pub use formats::ssa::SsaFile;
+pub use formats::vobsub::VobFile;
 use timetypes::TimeSpan;
 
 
